@@ -1,7 +1,6 @@
 #!/usr/local/bin/php-5.3
 <?php
 /*
-
  +-----------------------------------------------------------------------+
  | bin/indexcontacts.sh                                                  |
  |                                                                       |
@@ -18,9 +17,6 @@
  +-----------------------------------------------------------------------+
  | Author: Thomas Bruederli <roundcube@gmail.com>                        |
  +-----------------------------------------------------------------------+
-
- $Id$
-
 */
 
 define('INSTALL_PATH', realpath(dirname(__FILE__) . '/..') . '/' );
@@ -34,17 +30,18 @@ $RCMAIL = rcmail::get_instance();
 $db = $RCMAIL->get_dbh();
 $db->db_connect('w');
 
-if (!$db->is_connected() || $db->is_error())
-    die("No DB connection\n");
+if (!$db->is_connected() || $db->is_error()) {
+    rcube::raise_error("No DB connection", false, true);
+}
 
 // iterate over all users
 $sql_result = $db->query("SELECT user_id FROM " . $RCMAIL->config->get('db_table_users', 'users')." WHERE 1=1");
 while ($sql_result && ($sql_arr = $db->fetch_assoc($sql_result))) {
     echo "Indexing contacts for user " . $sql_arr['user_id'] . "...";
-    
+
     $contacts = new rcube_contacts($db, $sql_arr['user_id']);
     $contacts->set_pagesize(9999);
-    
+
     $result = $contacts->list_records();
     while ($result->count && ($row = $result->next())) {
         unset($row['words']);
