@@ -17,9 +17,6 @@
  +-----------------------------------------------------------------------+
  | Author: Thomas Bruederli <roundcube@gmail.com>                        |
  +-----------------------------------------------------------------------+
-
- $Id$
-
 */
 
 define('INSTALL_PATH', realpath(dirname(__FILE__) . '/..') . '/' );
@@ -28,16 +25,18 @@ require_once INSTALL_PATH . 'program/include/clisetup.php';
 require_once INSTALL_PATH . 'installer/rcube_install.php';
 
 // get arguments
-$opts = get_opt(array('v' => 'version'));
+$opts = rcube_utils::get_opt(array('v' => 'version'));
 
 // ask user if no version is specified
 if (!$opts['version']) {
   echo "What version are you upgrading from? Type '?' if you don't know.\n";
   if (($input = trim(fgets(STDIN))) && preg_match('/^[0-9.]+[a-z-]*$/', $input))
     $opts['version'] = $input;
+  else
+    $opts['version'] = RCMAIL_VERSION;
 }
 
-if ($opts['version'] && version_compare($opts['version'], RCMAIL_VERSION, '>'))
+if ($opts['version'] && version_compare(version_parse($opts['version']), version_parse(RCMAIL_VERSION), '>='))
   die("Nothing to be done here. Bye!\n");
 
 
@@ -127,7 +126,7 @@ if ($RCI->configured) {
         }
       }
       else {
-        echo "Please update your config files manually according to the above messages.\n\n";
+        echo "Please update your config files manually according to the above messages.\n";
       }
     }
 
@@ -146,36 +145,18 @@ if ($RCI->configured) {
 
   // check database schema
   if ($RCI->config['db_dsnw']) {
-    $DB = new rcube_mdb2($RCI->config['db_dsnw'], '', false);
-    $DB->db_connect('w');
-    if ($db_error_msg = $DB->is_error()) {
-      echo "Error connecting to database: $db_error_msg\n";
-      $success = false;
-    }
-    else if ($err = $RCI->db_schema_check($DB, false)) {
-      $updatefile = INSTALL_PATH . 'SQL/' . (isset($RCI->db_map[$DB->db_provider]) ? $RCI->db_map[$DB->db_provider] : $DB->db_provider) . '.update.sql';
-      echo "WARNING: Database schema needs to be updated!\n";
-      echo join("\n", $err) . "\n\n";
-      $success = false;
-      
-      if ($opts['version']) {
-        echo "Do you want to run the update queries to get the schmea fixed? (y/N)\n";
-        $input = trim(fgets(STDIN));
-        if (strtolower($input) == 'y') {
-          $success = $RCI->update_db($DB, $opts['version']);
-        }
-      }
-      
-      if (!$success)
-        echo "Open $updatefile and execute all queries below the comment with the currently installed version number.\n";
-    }
+    echo "Executing database schema update.\n";
+    system(INSTALL_PATH . "bin/updatedb.sh --package=roundcube --version=" . $opts['version']
+      . " --dir=" . INSTALL_PATH . DIRECTORY_SEPARATOR . "SQL", $res);
+
+    $success = !$res;
   }
-  
+
   // index contacts for fulltext searching
-  if (version_compare($opts['version'], '0.6', '<')) {
+  if (version_compare(version_parse($opts['version']), '0.6.0', '<')) {
     system(INSTALL_PATH . 'bin/indexcontacts.sh');
   }
-  
+
   if ($success) {
     echo "This instance of Roundcube is up-to-date.\n";
     echo "Have fun!\n";
@@ -186,6 +167,4 @@ else {
   echo "Open http://url-to-roundcube/installer/ in your browser and follow the instuctions.\n";
 }
 
-echo "\n";
-
 ?>
