@@ -1,3 +1,10 @@
+<?php
+
+if (!class_exists('rcube_install') || !is_object($RCI)) {
+    die("Not allowed! Please open installer/index.php instead.");
+}
+
+?>
 <form action="index.php" method="post">
 <input type="hidden" name="_step" value="2" />
 <?php
@@ -8,13 +15,11 @@ $RCI->load_defaults();
 // register these boolean fields
 $RCI->bool_config_props = array(
   'ip_check' => 1,
-  'enable_caching' => 1,
   'enable_spellcheck' => 1,
   'auto_create_user' => 1,
   'smtp_log' => 1,
   'prefer_html' => 1,
   'preview_pane' => 1,
-  'htmleditor' => 1,
   'debug_level' => 1,
 );
 
@@ -24,7 +29,7 @@ $_SESSION['allowinstaller'] = true;
 if (!empty($_POST['submit'])) {
   
   echo '<p class="notice">Copy or download the following configurations and save them in two files';
-  echo ' (names above the text box) within the <tt>'.RCMAIL_CONFIG_DIR.'</tt> directory of your RoundCube installation.<br/>';
+  echo ' (names above the text box) within the <tt>'.RCMAIL_CONFIG_DIR.'</tt> directory of your Roundcube installation.<br/>';
   echo ' Make sure that there are no characters outside the <tt>&lt;?php ?&gt;</tt> brackets when saving the files.</p>';
   
   $textbox = new html_textarea(array('rows' => 16, 'cols' => 60, 'class' => "configfile"));
@@ -60,6 +65,30 @@ echo $input_prodname->show($RCI->getprop('product_name'));
 <div>The name of your service (used to compose page titles)</div>
 </dd>
 
+<dt class="propname">support_url</dt>
+<dd>
+<?php
+
+$input_support = new html_inputfield(array('name' => '_support_url', 'size' => 50, 'id' => "cfgsupporturl"));
+echo $input_support->show($RCI->getprop('support_url'));
+
+?>
+<div>Provide an URL where a user can get support for this Roundcube installation.<br/>PLEASE DO NOT LINK TO THE ROUNDCUBE.NET WEBSITE HERE!</div>
+<p class="hint">Enter an absolute URL (inculding http://) to a support page/form or a mailto: link.</p>
+</dd>
+
+<dt class="propname">skin_logo</dt>
+<dd>
+<?php
+
+$input_skin = new html_inputfield(array('name' => '_skin_logo', 'size' => 50, 'id' => "cfgskinlogo"));
+echo $input_skin->show($RCI->getprop('skin_logo'));
+
+?>
+<div>Custom image to display instead of the Roundcube logo.</div>
+<p class="hint">Enter a URL relative to the document root of this Roundcube installation.</p>
+</dd>
+
 <dt class="propname">temp_dir</dt>
 <dd>
 <?php
@@ -71,6 +100,18 @@ echo $input_tempdir->show($RCI->getprop('temp_dir'));
 <div>Use this folder to store temp files (must be writeable for webserver)</div>
 </dd>
 
+<dt class="propname">des_key</dt>
+<dd>
+<?php
+
+$input_deskey = new html_inputfield(array('name' => '_des_key', 'size' => 30, 'id' => "cfgdeskey"));
+echo $input_deskey->show($RCI->getprop('des_key'));
+
+?>
+<div>This key is used to encrypt the users imap password before storing in the session record</div>
+<p class="hint">It's a random generated string to ensure that every installation has its own key.
+If you enter it manually please provide a string of exactly 24 chars.</p>
+</dd>
 
 <dt class="propname">ip_check</dt>
 <dd>
@@ -82,32 +123,9 @@ echo $check_ipcheck->show(intval($RCI->getprop('ip_check')), array('value' => 1)
 ?>
 <label for="cfgipcheck">Check client IP in session authorization</label><br />
 
-<p class="hint">This increases security but can cause sudden logouts when someone uses a proxy with changeing IPs.</p>
+<p class="hint">This increases security but can cause sudden logouts when someone uses a proxy with changing IPs.</p>
 </dd>
 
-<dt class="propname">des_key</dt>
-<dd>
-<?php
-
-$input_deskey = new html_inputfield(array('name' => '_des_key', 'size' => 30, 'id' => "cfgdeskey"));
-echo $input_deskey->show($RCI->getprop('des_key'));
-
-?>
-<div>This key is used to encrypt the users imap password before storing in the session record</div>
-<p class="hint">It's a random generated string to ensure that every installation has it's own key.
-If you enter it manually please provide a string of exactly 24 chars.</p>
-</dd>
-
-<dt class="propname">enable_caching</dt>
-<dd>
-<?php
-
-$check_caching = new html_checkbox(array('name' => '_enable_caching', 'id' => "cfgcache"));
-echo $check_caching->show(intval($RCI->getprop('enable_caching')), array('value' => 1));
-
-?>
-<label for="cfgcache">Cache messages in local database</label><br />
-</dd>
 
 <dt class="propname">enable_spellcheck</dt>
 <dd>
@@ -245,15 +263,10 @@ echo $input_syslogfacility->show($RCI->getprop('syslog_facility'), LOG_USER);
 <p>Database settings for read/write operations:</p>
 <?php
 
-require_once 'MDB2.php';
-
-$supported_dbs = array('MySQL' => 'mysql', 'MySQLi' => 'mysqli',
-    'PgSQL' => 'pgsql', 'SQLite' => 'sqlite');
-
 $select_dbtype = new html_select(array('name' => '_dbtype', 'id' => "cfgdbtype"));
-foreach ($supported_dbs AS $database => $ext) {
+foreach ($RCI->supported_dbs as $database => $ext) {
     if (extension_loaded($ext)) {
-        $select_dbtype->add($database, $ext);
+        $select_dbtype->add($database, substr($ext, 4));
     }
 }
 
@@ -262,7 +275,7 @@ $input_dbname = new html_inputfield(array('name' => '_dbname', 'size' => 20, 'id
 $input_dbuser = new html_inputfield(array('name' => '_dbuser', 'size' => 20, 'id' => "cfgdbuser"));
 $input_dbpass = new html_passwordfield(array('name' => '_dbpass', 'size' => 20, 'id' => "cfgdbpass"));
 
-$dsnw = MDB2::parseDSN($RCI->getprop('db_dsnw'));
+$dsnw = rcube_db::parse_dsn($RCI->getprop('db_dsnw'));
 
 echo $select_dbtype->show($RCI->is_post ? $_POST['_dbtype'] : $dsnw['phptype']);
 echo '<label for="cfgdbtype">Database type</label><br />';
@@ -343,12 +356,12 @@ $check_autocreate = new html_checkbox(array('name' => '_auto_create_user', 'id'
 echo $check_autocreate->show(intval($RCI->getprop('auto_create_user')), array('value' => 1));
 
 ?>
-<label for="cfgautocreate">Automatically create a new RoundCube user when log-in the first time</label><br />
+<label for="cfgautocreate">Automatically create a new Roundcube user when log-in the first time</label><br />
 
 <p class="hint">A user is authenticated by the IMAP server but it requires a local record to store settings
 and contacts. With this option enabled a new user record will automatically be created once the IMAP login succeeds.</p>
 
-<p class="hint">If this option is disabled, the login only succeeds if there's a matching user-record in the local RoundCube database
+<p class="hint">If this option is disabled, the login only succeeds if there's a matching user-record in the local Roundcube database
 what means that you have to create those records manually or disable this option after the first login.</p>
 </dd>
 
@@ -362,7 +375,7 @@ echo $text_sentmbox->show($RCI->getprop('sent_mbox'));
 ?>
 <div>Store sent messages in this folder</div>
 
-<p class="hint">Leave blank if sent messages should not be stored</p>
+<p class="hint">Leave blank if sent messages should not be stored. Note: folder must include namespace prefix if any.</p>
 </dd>
 
 <dt class="propname">trash_mbox</dt>
@@ -375,7 +388,7 @@ echo $text_trashmbox->show($RCI->getprop('trash_mbox'));
 ?>
 <div>Move messages to this folder when deleting them</div>
 
-<p class="hint">Leave blank if they should be deleted directly</p>
+<p class="hint">Leave blank if they should be deleted directly. Note: folder must include namespace prefix if any.</p>
 </dd>
 
 <dt class="propname">drafts_mbox</dt>
@@ -388,7 +401,7 @@ echo $text_draftsmbox->show($RCI->getprop('drafts_mbox'));
 ?>
 <div>Store draft messages in this folder</div>
 
-<p class="hint">Leave blank if they should not be stored</p>
+<p class="hint">Leave blank if they should not be stored. Note: folder must include namespace prefix if any.</p>
 </dd>
 
 <dt class="propname">junk_mbox</dt>
@@ -400,6 +413,10 @@ echo $text_junkmbox->show($RCI->getprop('junk_mbox'));
 
 ?>
 <div>Store spam messages in this folder</div>
+
+<p class="hint">Note: folder must include namespace prefix if any.</p>
+</dd>
+
 </dd>
 </dl>
 </fieldset>
@@ -501,22 +518,42 @@ echo $input_locale->show($RCI->getprop('language'));
 <dd>
 <?php
 
-$input_skin = new html_inputfield(array('name' => '_skin', 'size' => 30, 'id' => "cfgskin"));
+$input_skin = new html_select(array('name' => '_skin', 'id' => "cfgskin"));
+$input_skin->add($RCI->list_skins());
 echo $input_skin->show($RCI->getprop('skin'));
 
 ?>
 <div>Name of interface skin (folder in /skins)</div>
 </dd>
 
-<dt class="propname">pagesize <span class="userconf">*</span></dt>
+<dt class="propname">mail_pagesize <span class="userconf">*</span></dt>
 <dd>
 <?php
 
-$input_pagesize = new html_inputfield(array('name' => '_pagesize', 'size' => 6, 'id' => "cfgpagesize"));
-echo $input_pagesize->show($RCI->getprop('pagesize'));
+$pagesize = $RCI->getprop('mail_pagesize');
+if (!$pagesize) {
+    $pagesize = $RCI->getprop('pagesize');
+}
+$input_pagesize = new html_inputfield(array('name' => '_mail_pagesize', 'size' => 6, 'id' => "cfgmailpagesize"));
+echo $input_pagesize->show($pagesize);
 
 ?>
-<div>Show up to X items in list view.</div>
+<div>Show up to X items in the mail messages list view.</div>
+</dd>
+
+<dt class="propname">addressbook_pagesize <span class="userconf">*</span></dt>
+<dd>
+<?php
+
+$pagesize = $RCI->getprop('addressbook_pagesize');
+if (!$pagesize) {
+    $pagesize = $RCI->getprop('pagesize');
+}
+$input_pagesize = new html_inputfield(array('name' => '_addressbook_pagesize', 'size' => 6, 'id' => "cfgabookpagesize"));
+echo $input_pagesize->show($pagesize);
+
+?>
+<div>Show up to X items in the contacts list view.</div>
 </dd>
 
 <dt class="propname">prefer_html <span class="userconf">*</span></dt>
@@ -543,13 +580,16 @@ echo $check_prevpane->show(intval($RCI->getprop('preview_pane')));
 
 <dt class="propname">htmleditor <span class="userconf">*</span></dt>
 <dd>
+<label for="cfghtmlcompose">Compose HTML formatted messages</label>
 <?php
 
-$check_htmlcomp = new html_checkbox(array('name' => '_htmleditor', 'id' => "cfghtmlcompose", 'value' => 1));
-echo $check_htmlcomp->show(intval($RCI->getprop('htmleditor')));
+$select_htmlcomp = new html_select(array('name' => '_htmleditor', 'id' => "cfghtmlcompose"));
+$select_htmlcomp->add('never', 0);
+$select_htmlcomp->add('always', 1);
+$select_htmlcomp->add('on reply to HTML message only', 2);
+echo $select_htmlcomp->show(intval($RCI->getprop('htmleditor')));
 
 ?>
-<label for="cfghtmlcompose">Compose HTML formatted messages</label><br />
 </dd>
 
 <dt class="propname">draft_autosave <span class="userconf">*</span></dt>
@@ -571,8 +611,16 @@ echo $select_autosave->show(intval($RCI->getprop('draft_autosave')));
 <dd>
 <?php
 
+$mdn_opts = array(
+    0 => 'ask the user',
+    1 => 'send automatically',
+    3 => 'send receipt to user contacts, otherwise ask the user',
+    4 => 'send receipt to user contacts, otherwise ignore',
+    2 => 'ignore',
+);
+
 $select_mdnreq = new html_select(array('name' => '_mdn_requests', 'id' => "cfgmdnreq"));
-$select_mdnreq->add(array('ask the user', 'send automatically', 'ignore'), array(0, 1, 2));
+$select_mdnreq->add(array_values($mdn_opts), array_keys($mdn_opts));
 echo $select_mdnreq->show(intval($RCI->getprop('mdn_requests')));
 
 ?>
