@@ -374,17 +374,15 @@ class enigma_engine
     {
         // @TODO: Handle big bodies using (temp) files
         // @TODO: caching of verification result
-        
-         $sig = $this->pgp_driver->verify($msg_body, $sig_body);
+        $sig = $this->pgp_driver->verify($msg_body, $sig_body);
 
-         if (($sig instanceof enigma_error) && $sig->getCode() != enigma_error::E_KEYNOTFOUND)
-             raise_error(array(
+        if (($sig instanceof enigma_error) && $sig->getCode() != enigma_error::E_KEYNOTFOUND)
+            rcube::raise_error(array(
                 'code' => 600, 'type' => 'php',
                 'file' => __FILE__, 'line' => __LINE__,
-                'message' => "Enigma plugin: " . $error->getMessage()
+                'message' => "Enigma plugin: " . $sig->getMessage()
                 ), true, false);
 
-//print_r($sig);
         return $sig;
     }
 
@@ -399,11 +397,9 @@ class enigma_engine
     {
         // @TODO: Handle big bodies using (temp) files
         // @TODO: caching of verification result
-        
+        $key = ''; $pass = ''; // @TODO
         $result = $this->pgp_driver->decrypt($msg_body, $key, $pass);
 
-//print_r($result);
-
         if ($result instanceof enigma_error) {
             $err_code = $result->getCode();
             if (!in_array($err_code, array(enigma_error::E_KEYNOTFOUND, enigma_error::E_BADPASS)))
@@ -430,7 +426,7 @@ class enigma_engine
     {
         $this->load_pgp_driver();
         $result = $this->pgp_driver->list_keys($pattern);
-    
+
         if ($result instanceof enigma_error) {
             raise_error(array(
                 'code' => 600, 'type' => 'php',
@@ -438,7 +434,7 @@ class enigma_engine
                 'message' => "Enigma plugin: " . $result->getMessage()
                 ), true, false);
         }
-        
+
         return $result;
     }
 
@@ -503,7 +499,7 @@ class enigma_engine
         $mime_id = get_input_value('_part', RCUBE_INPUT_POST);
 
         if ($uid && $mime_id) {
-            $part = $this->rc->imap->get_message_part($uid, $mime_id);
+            $part = $this->rc->storage->get_message_part($uid, $mime_id);
         }
 
         if ($part && is_array($result = $this->import_key($part))) {
@@ -512,7 +508,7 @@ class enigma_engine
         }
         else
             $this->rc->output->show_message('enigma.keysimportfailed', 'error');
-    
+
         $this->rc->output->send();
     }
 
@@ -528,7 +524,7 @@ class enigma_engine
         // @TODO: Create such function in core
         // @TODO: Handle big bodies using file handles
         if (!isset($part->body)) {
-            $part->body = $this->rc->imap->get_message_part(
+            $part->body = $this->rc->storage->get_message_part(
                 $uid, $part->mime_id, $part);
         }
     }
